@@ -1,7 +1,8 @@
+from zebrazoom.code.preprocessImage import preprocessImage
 import numpy as np
 import cv2
 
-def headEmbededFrameSequential(cap, videoPath, frameNumber):
+def headEmbededFrameSequential(cap, videoPath, frameNumber, hyperparameters):
   
   debug = 0
   
@@ -16,6 +17,12 @@ def headEmbededFrameSequential(cap, videoPath, frameNumber):
     cap.set(1, frameNumber)
     ret, frame = cap.read()
   
+  if hyperparameters["invertBlackWhiteOnImages"]:
+    frame = 255 - frame
+  
+  if hyperparameters["imagePreProcessMethod"]:
+    frame = preprocessImage(frame, hyperparameters)
+  
   kernel = np.ones((8,8),np.float32)/25
   thres1  = cv2.filter2D(frame,-1,kernel)
   retval, thres1 = cv2.threshold(thres1, 80, 255, cv2.THRESH_BINARY)
