@@ -8,12 +8,15 @@ from zebrazoom.code.createValidationVideo import createValidationVideo
 from zebrazoom.code.getHyperparameters import getHyperparameters
 import zebrazoom.code.popUpAlgoFollow as popUpAlgoFollow
 from zebrazoom.code.dataPostProcessing.dataPostProcessing import dataPostProcessing
+from zebrazoom.code.fasterMultiprocessing import fasterMultiprocessing
 
 import sys
 import pickle
 import os
 import shutil
 import time
+import cv2
+import json
 
 from zebrazoom.code.vars import getGlobalVariables
 globalVariables = getGlobalVariables()
@@ -64,8 +67,26 @@ def mainZZ(pathToVideo, videoName, videoExt, configFile, argv):
   previouslyAcquiredTrackingDataForDebug = []
 
   # Getting hyperparameters
-  hyperparameters = getHyperparameters(configFile, videoNameWithExt, os.path.join(pathToVideo, videoNameWithExt), argv)
+  [hyperparameters, configFile] = getHyperparameters(configFile, videoNameWithExt, os.path.join(pathToVideo, videoNameWithExt), argv)
   
+  # Checking first frame and last frame value
+  cap   = cv2.VideoCapture(os.path.join(pathToVideo, videoNameWithExt))
+  nbFrames = int(cap.get(cv2.CAP_PROP_FRAME_COUNT))
+  cap.release()
+  if hyperparameters["firstFrame"] < 0:
+    print("Error: The parameter 'firstFrame' in your configuration file is too small")
+    raise NameError("Error: The parameter 'firstFrame' in your configuration file is too small")
+  if hyperparameters["firstFrame"] > nbFrames:
+    print("Error: The parameter 'firstFrame' in your configuration file is too big")
+    raise NameError("Error: The parameter 'firstFrame' in your configuration file is too big")
+  if (hyperparameters["lastFrame"] < 0) or (hyperparameters["lastFrame"] <= hyperparameters["firstFrame"]):
+    print("Error: The parameter 'lastFrame' in your configuration file is too small")
+    raise NameError("Error: The parameter 'lastFrame' in your configuration file is too small")
+  if hyperparameters["lastFrame"] > nbFrames:
+    print("Error: The parameter 'lastFrame' in your configuration file is too big")
+    raise NameError("Error: The parameter 'lastFrame' in your configuration file is too big")
+  
+  # Setting output folder
   outputFolderVideo = os.path.join(hyperparameters["outputFolder"], videoName)
   
   # Launching GUI algoFollower if necessary
@@ -95,9 +116,9 @@ def mainZZ(pathToVideo, videoName, videoExt, configFile, argv):
           time.sleep(0.1)
     
   # Saving the configuration file used
-  if type(configFile) == str:
-    print(os.path.join(outputFolderVideo, 'configUsed.json'), outputFolderVideo)
-    shutil.copyfile(configFile, os.path.join(outputFolderVideo, 'configUsed.json'))
+  with open(os.path.join(outputFolderVideo, 'configUsed.json'), 'w') as outfile:
+    json.dump(configFile, outfile)
+  
 
   # Getting well positions
   if hyperparameters["headEmbeded"]:
@@ -120,6 +141,7 @@ def mainZZ(pathToVideo, videoName, videoExt, configFile, argv):
       pickle.dump(wellPositions,outfile)
     outfile.close()
   if int(hyperparameters["exitAfterWellsDetection"]):
+    print("exitAfterWellsDetection")
     if hyperparameters["popUpAlgoFollow"]:
       popUpAlgoFollow.prepend("ZebraZoom Analysis finished for " + videoName)
     raise ValueError
@@ -139,38 +161,46 @@ def mainZZ(pathToVideo, videoName, videoExt, configFile, argv):
       pickle.dump(background,outfile)
     outfile.close()
   if hyperparameters["exitAfterBackgroundExtraction"]:
+    print("exitAfterBackgroundExtraction")
     raise ValueError
   
   # Tracking and extraction of parameters
-  if globalVariables["noMultiprocessing"] == 0:
-    if hyperparameters["onlyTrackThisOneWell"] == -1:
-      # for all wells, in parallel
-      processes = []
-      for wellNumber in range(0,hyperparameters["nbWells"]):
-        p = Process(target=getParametersForWell, args=(os.path.join(pathToVideo, videoNameWithExt), background, wellNumber, wellPositions, output, previouslyAcquiredTrackingDataForDebug, hyperparameters, videoName))
-        p.start()
-        processes.append(p)
-    else:
-      # for just one well
-      processes = [1]
-      getParametersForWell(os.path.join(pathToVideo, videoNameWithExt), background, hyperparameters["onlyTrackThisOneWell"], wellPositions, output, previouslyAcquiredTrackingDataForDebug, hyperparameters, videoName)
+  if hyperparameters["fasterMultiprocessing"] == 1:
+    processes = -1
+    output2 = fasterMultiprocessing(os.path.join(pathToVideo, videoNameWithExt), background, wellPositions, [], hyperparameters, videoName)
   else:
-    if hyperparameters["onlyTrackThisOneWell"] == -1:
-      processes = [1 for i in range(0, hyperparameters["nbWells"])]
-      for wellNumber in range(0,hyperparameters["nbWells"]):
-        getParametersForWell(os.path.join(pathToVideo, videoNameWithExt), background, wellNumber, wellPositions, output, previouslyAcquiredTrackingDataForDebug, hyperparameters, videoName)
+    if globalVariables["noMultiprocessing"] == 0:
+      if hyperparameters["onlyTrackThisOneWell"] == -1:
+        # for all wells, in parallel
+        processes = []
+        for wellNumber in range(0,hyperparameters["nbWells"]):
+          p = Process(target=getParametersForWell, args=(os.path.join(pathToVideo, videoNameWithExt), background, wellNumber, wellPositions, output, previouslyAcquiredTrackingDataForDebug, hyperparameters, videoName))
+          p.start()
+          processes.append(p)
+      else:
+        # for just one well
+        processes = [1]
+        getParametersForWell(os.path.join(pathToVideo, videoNameWithExt), background, hyperparameters["onlyTrackThisOneWell"], wellPositions, output, previouslyAcquiredTrackingDataForDebug, hyperparameters, videoName)
     else:
-      processes = [1]
-      getParametersForWell(os.path.join(pathToVideo, videoNameWithExt), background, hyperparameters["onlyTrackThisOneWell"], wellPositions, output, previouslyAcquiredTrackingDataForDebug, hyperparameters, videoName)
+      if hyperparameters["onlyTrackThisOneWell"] == -1:
+        processes = [1 for i in range(0, hyperparameters["nbWells"])]
+        for wellNumber in range(0,hyperparameters["nbWells"]):
+          getParametersForWell(os.path.join(pathToVideo, videoNameWithExt), background, wellNumber, wellPositions, output, previouslyAcquiredTrackingDataForDebug, hyperparameters, videoName)
+      else:
+        processes = [1]
+        getParametersForWell(os.path.join(pathToVideo, videoNameWithExt), background, hyperparameters["onlyTrackThisOneWell"], wellPositions, output, previouslyAcquiredTrackingDataForDebug, hyperparameters, videoName)
   
   # Sorting wells after the end of the parallelized calls end
-  dataPerWellUnsorted = [output.get() for p in processes]
+  if processes != -1:
+    dataPerWellUnsorted = [output.get() for p in processes]
+  else:
+    dataPerWellUnsorted = output2
   paramDataPerWell = [[]] * (hyperparameters["nbWells"])
   trackingDataPerWell = [[]] * (hyperparameters["nbWells"])
   for data in dataPerWellUnsorted:
     paramDataPerWell[data[0]]    = data[1]
     trackingDataPerWell[data[0]] = data[2]
-  if hyperparameters["onlyTrackThisOneWell"] == -1 and globalVariables["noMultiprocessing"] == 0:
+  if processes != -1 and hyperparameters["onlyTrackThisOneWell"] == -1 and globalVariables["noMultiprocessing"] == 0:
     for p in processes:
       p.join()
   if (hyperparameters["freqAlgoPosFollow"] != 0):
@@ -181,18 +211,44 @@ def mainZZ(pathToVideo, videoName, videoExt, configFile, argv):
     outfile = open(os.path.join(outputFolderVideo, 'intermediaryTracking.txt'),'wb')
     pickle.dump(trackingDataPerWell,outfile)
     outfile.close()
+    if (hyperparameters["freqAlgoPosFollow"] != 0):
+      print("intermediary results saved")
     
   if hyperparameters["debugPauseBetweenTrackAndParamExtract"] != "justSaveTrackData":
     # Creating super structure
     superStruct = createSuperStruct(paramDataPerWell, wellPositions, hyperparameters)
   
     # Creating validation video
-    if hyperparameters["createValidationVideo"]:
-      infoFrame = createValidationVideo(os.path.join(pathToVideo, videoNameWithExt), superStruct, hyperparameters)
+    if hyperparameters["copyOriginalVideoToOutputFolderForValidation"]:
+      shutil.copyfile(os.path.join(pathToVideo, videoNameWithExt), os.path.join(os.path.join(hyperparameters["outputFolder"], hyperparameters["videoName"]), hyperparameters["videoName"] + '.avi'))
+    else:
+      if hyperparameters["createValidationVideo"]:
+        infoFrame = createValidationVideo(os.path.join(pathToVideo, videoNameWithExt), superStruct, hyperparameters)
     
     # Various post-processing options depending on configuration file choices
     dataPostProcessing(outputFolderVideo, superStruct, hyperparameters, videoName)
-
+  
+  # Copying output result folder in another folder
+  if len(hyperparameters["additionalOutputFolder"]):
+    if os.path.isdir(hyperparameters["additionalOutputFolder"]):
+      if hyperparameters["additionalOutputFolderOverwriteIfAlreadyExist"]:
+        shutil.rmtree(hyperparameters["additionalOutputFolder"])
+        while True:
+          try:
+            shutil.copytree(outputFolderVideo, hyperparameters["additionalOutputFolder"])
+            break
+          except OSError as e:
+            print("waiting inside except")
+            time.sleep(0.1)
+          else:
+            print("waiting")
+            time.sleep(0.1)
+      else:
+        print("The path " + hyperparameters["additionalOutputFolder"] + " already exists. New folder not created. If you want the folder to be overwritten in such situation in future executions, set the parameter 'additionalOutputFolderOverwriteIfAlreadyExist' to 1 in your configuration file.")
+    else:
+      shutil.copytree(outputFolderVideo, hyperparameters["additionalOutputFolder"])
+  
+  
   if hyperparameters["popUpAlgoFollow"]:
     popUpAlgoFollow.prepend("ZebraZoom Analysis finished for " + videoName)
     # popUpAlgoFollow.prepend("")
